pub struct Symlink {
pub name: String,
pub target: Vec<u8>,
}Expand description
Symlink object pointing to a target path.
Fields
name: Stringtarget: Vec<u8>Trait Implementations
Sourceimpl<D: ResourceDialect> Decode<Symlink, D> for Symlink
impl<D: ResourceDialect> Decode<Symlink, D> for Symlink
Sourceimpl<D: ResourceDialect, T0: Encode<BoundedString<255>, D>, T1: Encode<Vector<u8, 4095>, D>> Encode<Symlink, D> for (T0, T1)
impl<D: ResourceDialect, T0: Encode<BoundedString<255>, D>, T1: Encode<Vector<u8, 4095>, D>> Encode<Symlink, D> for (T0, T1)
impl Eq for Symlink
Sourceimpl Ord for Symlink
impl Ord for Symlink
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for Symlink
impl PartialOrd for Symlink
impl Persistable for Symlink
impl StructuralPartialEq for Symlink
Sourceimpl TypeMarker for Symlink
impl TypeMarker for Symlink
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for Symlink
impl RefUnwindSafe for Symlink
impl Send for Symlink
impl Sync for Symlink
impl Unpin for Symlink
impl UnsafeUnpin for Symlink
impl UnwindSafe for Symlink